==> tecfy_corev2_package-1.1.30.tar.gz: lib/models/entity/property_text.model.dart <==
part of tecfy_corev2_client_package;

class PropertyText extends Property {
  int maxLength = 25000;
  int minLength = 0;
  int lines = 1;

  bool isMultiLine = false;

  bool isPassword = false;
  bool isEmail = false;
  bool isBarcode = false;

  PropertyText(
      {required String dbName,
      required String nameAr,
      required String nameEn,
      bool isRequired = false,
      bool readOnly = false,
      this.isMultiLine = false,
      this.isPassword = false,
      this.isEmail = false,
      this.isBarcode = false,
      this.lines = 1,
      this.maxLength = 25000,
      this.minLength = 0})
      : super(
            dbName: dbName,
            nameAr: nameAr,
            nameEn: nameEn,
            readOnly: readOnly,
            propertyType: PropertyTypes.Text,
            valueType: ValueTypes.Text,
            isRequired: isRequired);

  PropertyText.fromMap(Map<String, dynamic> row) : super.fromMap(row) {
    maxLength = row['maxLength'] ?? 25000;
    minLength = row['minLength'] ?? 0;
    lines = row['lines'] ?? 1;
    isMultiLine = row['isMultiLine'] ?? false;
    isPassword = row['isPassword'] ?? false;
    isBarcode = row['isBarcode'] ?? false;
    isEmail = row['isEmail'] ?? false;
  }

  @override
  OperationResult isValid(data) {
    if (!super.isValid(data).success) return super.isValid(data);

    if (isRequired && data == null)
      return OperationResult(
          success: false,
          message: "${AppLocale.translate('Text Value Required')} ($name)");

    if (data != null && (!(data is String) || (isRequired && data.length == 0)))
      return OperationResult(
          success: false,
          message: "${AppLocale.translate('Text Value Required')} ($name)");

    if (data != null && data.length > maxLength)
      return OperationResult(
          success: false,
          message: "${AppLocale.translate('Max Length exceped')} ($name)");

    if (data != null && data.length < minLength)
      return OperationResult(
          success: false,
          message: "${AppLocale.translate('Min Length not reached')} ($name)");

    return OperationResult(success: true);
  }

  /// get the value and bind tp display widget
  Widget getDisplayWidget(Map<String, dynamic> data, {TextStyle? textStyle}) {
    return Text(data[dbName]?.toString() ?? '', style: textStyle);
  }

  /// get the value in text
  String getDisplayText(Map<String, dynamic> data) {
    return data[dbName]?.toString() ?? '';
  }

  Future<bool> getDefaultValue(Map<String, dynamic> data) async {
    if (data[dbName] != null && data[dbName].toString().isNotEmpty)
      return false;
    if (defaultString?.isNotEmpty ?? false) {
      data[dbName] = defaultString;
      return true;
    }
    return false;
  }
}

==> tecfy_corev2_package-1.1.35.tar.gz: lib/models/entity/property_text.model.dart <==
part of tecfy_corev2_client_package;

class PropertyText extends Property {
  int maxLength = 25000;
  int minLength = 0;
  int lines = 1;

  bool isMultiLine = false;

  bool isPassword = false;
  bool isEmail = false;
  bool isBarcode = false;

  PropertyText(
      {required String dbName,
      required String nameAr,
      required String nameEn,
      bool isRequired = false,
      bool readOnly = false,
      this.isMultiLine = false,
      this.isPassword = false,
      this.isEmail = false,
      this.isBarcode = false,
      this.lines = 1,
      this.maxLength = 25000,
      this.minLength = 0})
      : super(
            dbName: dbName,
            nameAr: nameAr,
            nameEn: nameEn,
            readOnly: readOnly,
            propertyType: PropertyTypes.Text,
            valueType: ValueTypes.Text,
            isRequired: isRequired);

  PropertyText.fromMap(Map<String, dynamic> row) : super.fromMap(row) {
    maxLength = row['maxLength'] ?? 25000;
    minLength = row['minLength'] ?? 0;
    lines = row['lines'] ?? 1;
    isMultiLine = row['isMultiLine'] ?? false;
    isPassword = row['isPassword'] ?? false;
    isBarcode = row['isBarcode'] ?? false;
    isEmail = row['isEmail'] ?? false;
  }

  @override
  OperationResult isValid(data) {
    if (!super.isValid(data).success) return super.isValid(data);

    if (isRequired && data == null)
      return OperationResult(
          success: false,
          message: "${AppLocale.translate('Text Value Required')} ($name)");

    if (data != null && (!(data is String) || (isRequired && data.length == 0)))
      return OperationResult(
          success: false,
          message: "${AppLocale.translate('Text Value Required')} ($name)");

    if (data != null && data.length > maxLength)
      return OperationResult(
          success: false,
          message: "${AppLocale.translate('Max Length exceped')} ($name)");

    if (data != null && data.length < minLength)
      return OperationResult(
          success: false,
          message: "${AppLocale.translate('Min Length not reached')} ($name)");

    return OperationResult(success: true);
  }

  /// get the value and bind tp display widget
  Widget getDisplayWidget(Map<String, dynamic> data, {TextStyle? textStyle}) {
    return Text(getDisplayText(data), style: textStyle);
  }

  /// get the value in text
  String getDisplayText(Map<String, dynamic> data) {
    // print('====================%%=========================');
    // print(data);
    // print(dbName);
    // print(data[dbName]);
    //
    // print('====================%%=========================');
    // if (dbName.contains('.')) {
    //   // print(dbName.split('.'));
    //   if (MapService.getValue(data, dbName) != null) {
    //     // print('***********************************************');
    //     // print(MapService.getValue(data, dbName));
    return MapService.getValue(data, dbName).toString();
    //   }
    //  }
    // return data[dbName]?.toString() ?? '';
  }

  Future<bool> getDefaultValue(Map<String, dynamic> data) async {
    var value = MapService.getValue(data, dbName);
    if (value != null && value.toString().isNotEmpty) return false;
    if (defaultString?.isNotEmpty ?? false) {
      // data[dbName] = defaultString;
      MapService.updateValue(data, dbName, defaultString ?? '');
      return true;
    }
    return false;
  }
}
